"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const express_1 = require("express");
const core_types_1 = require("./types/core.types");
const helpers_1 = require("./helpers");
/**
 * Recursive. Takes the ZemiRoutes passed in and returns an Express router
 * (either created or specified as the second argument) with each ZemiRoute as
 * an express route under it.
 * @param routes {Array<ZemiRoute>} - An array of ZemiRoutes.
 * @param [router] {Router} - An Express router to be used for adding ZemiRoutes; router is auto-created if not passed in.
 * @returns {Router} - A router with all ZemiRoutes built into it.
 * @type{(routes: Array<ZemiRoute>, router: Router)=> Router}
 */
function Zemi(routes, router = (0, express_1.Router)({ mergeParams: true })) {
    router.use(function (request, response, next) {
        request.routeDefinitions = (0, helpers_1.buildRouteDefinitions)(routes);
        request.allowedResponseHttpCodes = (0, helpers_1.buildResponsesPerNamedRoute)(routes);
        next();
    });
    routes.forEach((route) => {
        const path = (0, helpers_1.paramPathToValidExpressPath)(route.path);
        route.middleware &&
            route.middleware.forEach((middleware) => router.use((request, response, next) => middleware(request, response, next)));
        const methods = Object.values(core_types_1.ZemiMethod);
        methods.forEach((method) => {
            const handlerDefinition = route[method];
            if (handlerDefinition && handlerDefinition.handler) {
                const routeDef = (0, helpers_1.buildRouteDefinition)(path, route.name);
                router[method](path, (request, response, next) => handlerDefinition.handler(request, response, next, routeDef));
            }
        });
        route.routes && router.use(path, Zemi(route.routes));
    });
    return router;
}
exports.default = Zemi;
//# sourceMappingURL=core.js.map