import { ZemiRoute, ZemiRouteDefinition } from "./types/core.types";
import { NamedRoute } from "./types/helpers.types";
import { OpenApiParameterObject } from "./types/openapi.types";
/**
 * Builds a route-definition with the name and path specified.
 * Will build an array of strings with the parameters specified in the path, and
 * a reverse function -- which will substitute params in the path for values
 * passed in via an object -- to the route-definition.
 * @param path {string} - The path for this route-definition.
 * @param name {string} - The name for this route-definition.
 * @return {ZemiRouteDefinition} - A route-definition with the name, path, parameters in the path, and reverse function for said path.
 * @type{(path: string, name:string)=> ZemiRouteDefinition}
 */
export declare function buildRouteDefinition(path: string, name: string): ZemiRouteDefinition;
/**
 * Recursive. Builds a route-definition for each ZemiRoute in the array.
 * Converts zemi paths (path that has params with their types built in)
 * into valid Express paths. Used to add route-definitions to ZemiRequest
 * object.
 * @param routes {Array<ZemiRoute>} - An array of ZemiRoutes.
 * @param [prefix] {NamedRoute} - The prefix to use for this route, if nested, so that its parent's path is added to its path.
 * @returns {Record<string, ZemiRouteDefinition>} - An object where each key is a route name and the value is that routes' route-definition.
 * @type{(routes: Array<ZemiRoute>, prefix?: NamedRoute)=> Record<string, ZemiRouteDefinition>}
 */
export declare function buildRouteDefinitions(routes: Array<ZemiRoute>, prefix?: NamedRoute): Record<string, ZemiRouteDefinition>;
/**
 * Recursive. Builds an object with route names as keys and values are objects mapping
 * HTTP methods to array of response codes for those same methods. Used to add
 * allowedResponseCodes to ZemiRequest object.
 * @param routes {Array<ZemiRoute>} - An array of ZemiRoutes.
 * @param [prefix] {NamedRoute} - The prefix to use for this route, if nested, so that its parent's path is added to its path.
 * @returns {Record<string, Record<string, Array<string>>>} - An object where each key is a route name and the value is an object whose keys map to an array of allowed response codes, as strings.
 * @type{(routes: Array<ZemiRoute>, prefix?: NamedRoute)=> Record<string, Record<string, Array<string>>>}
 */
export declare function buildResponsesPerNamedRoute(routes: Array<ZemiRoute>, prefix?: string): Record<string, Record<string, Array<string>>>;
/**
 * Converts a zemi-style path -- where parameters are specified as
 * `{param|type}` -- to a valid Express path (parameters are defined as
 * `:param`). Used to generate paths for Express routes, from ZemiRoutes.
 * @param path {string} - A path that has parameters specified as `{param|type}`.
 * @return {string} - A valid Express path, that has parameters specified as `:param`.
 * @type{(path: string)=> string}
 */
export declare function paramPathToValidExpressPath(path: string): string;
/**
 * Converts a zemi-style path -- where parameters are specified as
 * `{param|type}` -- to a valid OpenApi path (parameters are defined as
 * `{param}`). Used to generate paths for OpenApi spec, from ZemiRoutes.
 * @param path {string} - A path that has parameters specified as `{param|type}`.
 * @return {string} - A valid OpenApi path, that has parameters specified as `{param}`.
 * @type{(path: string)=> string}
 */
export declare function paramPathToOpenApiPath(path: string): string;
/**
 * Converts a zemi-style path -- where parameters are specified as
 * `{param|type}` -- to an OpenApi ParameterObject.
 * Used when generating ParameterObjects, from ZemiRoutes, for OpenApi spec generation.
 * @param path {string} - A path that has parameters specified as `{param|type}`.
 * @return {Array<OpenApiParameterObject>} - An array of OpenApi ParameterObject.
 * @type{(path: string)=> Array<OpenApiParameterObject>}
 */
export declare function paramPathToOpenApiParamObject(path: string): Array<OpenApiParameterObject>;
